@@ -320,6 +320,71 @@ class LPMain:
         x = np.array(problem.solution.get_values())
         return x
             
+
+    def results_to_excel(self,path):
+        '''
+        Exports the results of the LP model to an Excel file. 
+        Iterates through each object in 'obj_lst', extracts state variables and their results, 
+        and writes them to separate sheets in an Excel file.
+
+        Parameters:
+        path (str): The file path where the Excel file should be saved.
+        '''
+        import pandas as pd
+        with pd.ExcelWriter(path,engine='openpyxl') as writer:
+            for obj in self.obj_lst:
+                if obj.name=='':
+                    name=type(obj).__name__
+                else:
+                    name = obj.name
+                df = pd.DataFrame(columns=['Name','Unit','Type','Min','Max','Timedependet'])
+                # df.columns = ['Name','Unit','Type','Min','Max','Timedependet']
+                for var in obj.stateVar_lst:
+                    td = type(var) == LPStateVar_timedep
+                    df = pd.concat([df,pd.DataFrame.from_records([{'Name':var.name,'Unit':var.unit,'Type':var.vtype,'Min':var.lb,'Max':var.ub,'Timedependet':td}])])
+                if len(df)>0:
+                    df.to_excel(writer,sheet_name=f'{name} - Variables',index=False)
+                # Result of timedependent variables
+                df = pd.DataFrame()
+                df['t']=range(self.inputdata.steps)
+                for var in obj.stateVar_lst:
+                    df[var.name]=var.result
+                if df.shape[1]>1:
+                    df.to_excel(writer,sheet_name=f'{name} - Results',index=False)
+        self.optimize_excel_col_width(path)
+        
+    def optimize_excel_col_width(self,path):
+        '''
+        optimizes the width of the excel columns so the full title of each column can be read
+        '''
+        from openpyxl import load_workbook
+        wb = load_workbook(path)
+        ws = wb.active
+
+        # Funktion zum Berechnen der optimalen Breite für jede Spalte
+        def get_optimal_width(column_values):
+            max_length = 0
+            for value in column_values:
+                max_length = max(max_length, len(str(value)))
+            return max_length + 2  # Zusätzlicher Platz für Puffer
+
+        # Schleife durch jede Spalte im DataFrame
+        for sheet_name in wb.sheetnames:
+            ws = wb[sheet_name]
+            
+            # Spalten als Liste holen
+            columns = list(ws.iter_rows(min_row=1, max_row=1, values_only=True))[0]
+
+            # Schleife durch jede Spalte im aktuellen Blatt
+            for col_idx, column in enumerate(columns, start=1):  # Spaltenindex beginnt bei 1 in Excel
+                col_letter = ws.cell(row=1, column=col_idx).column_letter  # Spaltenbuchstabe
+                column_values = [cell.value for cell in ws[col_letter]]  # Alle Werte der Spalte
+                optimal_width = get_optimal_width(column_values)
+                ws.column_dimensions[col_letter].width = optimal_width
+
+        # Speichern der angepassten Excel-Datei
+        wb.save(path)
+
     def show_lp_system(self,window_size="1225x850",width=500):
         '''
         Displays a graphical user interface (GUI) for visualizing the Linear Programming (LP) system. 
@@ -518,4 +583,6 @@ class ScrollableFrame(ttk.Frame):
 
     def _unbind_mousewheel(self, event):
         self.canvas.unbind_all("<MouseWheel>")
-        self.canvas.unbind_all("<Shift-MouseWheel>")
\ No newline at end of file
+        self.canvas.unbind_all("<Shift-MouseWheel>")
+    
+    
\ No newline at end of file
